"""
Copyright 2009  Blub

A startup script for HttpServer.
This file is part of PebCache.

PebCache is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published
by the Free Software Foundation, version 2 of the License.

PebCache is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with PebCache.  If not, see <http://www.gnu.org/licenses/>.
"""

##builtin
import logging
import os

##own
from Config import Config
from Http.HttpServer import HttpServer
from LogController import LogController

#version
version = '0.1.6'

#application folder
progPath = os.getcwd()

#create log controller
logController = LogController((('consoleLog', 'consoleLog', {'logLevel':'critical',
                                                             'logFormat':'%(asctime)s %(levelname)-8s %(name)-22s - %(message)s'}),
                               ('fileLog'   , 'fileLog'   , {'filename':os.path.join(progPath, u'Logs', u'log'),
                                                             'logLevel':'info',
                                                             'logFormat':'%(asctime)s %(levelname)-8s %(name)-22s - %(message)s',
                                                             'fileMaxBytes':10485760,
                                                             'fileMaxRotatedCount':4})))
                                                                
#create config, set defaults
configDefaults = {'http':{'maxHeaderSize':(4096, 'int'),
                          'maxBodySize':(1048576, 'int')},
                  'logging':{'consoleLoglevel':('critical', 'str'),
                             'fileLoglevel':('info', 'str')},
                  'i2p':{'SamIp':('127.0.0.1', 'ip'),
                         'SamPort':(7656, 'port'),
                         'SamSessionName':('PebCache', 'str'),
                         'SamInboundQuantity':(3, 'int'),
                         'SamInboundBackupQuantity':(0, 'int'),
                         'SamInboundLength':(1, 'int'),
                         'SamInboundLengthVariance':(1, 'int'),
                         'SamInboundAllowZeroHop':(False, 'bool'),
                         'SamOutboundQuantity':(2, 'int'),
                         'SamOutboundBackupQuantity':(0, 'int'),
                         'SamOutboundLength':(1, 'int'),
                         'SamOutboundLengthVariance':(1, 'int'),
                         'SamOutboundAllowZeroHop':(False, 'bool')
                            },
                  'Handler':{}}
                                    
config = Config(os.path.join(progPath, 'HttpServer.cfg'), configDefaults=configDefaults)

#set loglevel
logController.changeHandlerLoglevel('consoleLog', config.get('logging','consoleLoglevel'))
logController.changeHandlerLoglevel('fileLog', config.get('logging','fileLoglevel'))

#startup server
server = HttpServer(progPath, config, version)
server.run()

#cleanup logging related things
logController.shutdown()